# Basic Exception to handle not found companies
class CompanySnapshotNotFoundException(Exception):
    pass
